@@ -35,7 +35,6 @@ class TaskBuildWrapper:
     here and return it so at the end of the DAG execution, a message with the
     traceback can be printed
     """
-
     def __init__(self, task):
         self.task = task
 
@@ -81,6 +80,13 @@ class Parallel(Executor):
         # add at the top of your pipeline.yaml
         executor: parallel
 
+        tasks:
+          - source: script.py
+            nb_product_key: [nb_ipynb, nb_html]
+            product:
+                nb_ipynb: nb.ipynb
+                nb_html: report.html
+
 
     Python API:
 
@@ -90,6 +96,35 @@ class Parallel(Executor):
     >>> dag = DAG(executor=Parallel(processes=2)) # customize
 
 
+    DAG can exit gracefully on function tasks (PythonCallable):
+
+    >>> from ploomber.products import File
+    >>> from ploomber.tasks import PythonCallable
+    >>> from ploomber.exceptions import DAGBuildEarlyStop
+    >>> # A PythonCallable function that raises DAGBuildEarlyStop
+    >>> def early_stop_root(product):
+    ...     raise DAGBuildEarlyStop('Ending gracefully')
+
+    >>> # Since DAGBuildEarlyStop is raised, DAG will exit gracefully.
+    >>> dag = DAG(executor='parallel')
+    >>> t = PythonCallable(early_stop_root, File('file.txt'), dag=dag)
+    >>> dag.build()  # doctest: +SKIP
+
+
+    DAG can also exit gracefully on notebook tasks:
+
+    >>> from pathlib import Path
+    >>> from ploomber.tasks import NotebookRunner
+    >>> from ploomber.products import File
+    >>> def early_stop():
+    ...     raise DAGBuildEarlyStop('Ending gracefully')
+
+    >>> # Use task-level hook "on_finish" to exit DAG gracefully.
+    >>> dag = DAG(executor='parallel')
+    >>> t = NotebookRunner(Path('nb.ipynb'), File('report.html'), dag=dag)
+    >>> t.on_finish = early_stop
+    >>> dag.build()  # doctest: +SKIP
+
     Notes
     -----
     If any task crashes, downstream tasks execution is aborted, building
