@@ -4,8 +4,8 @@ from functools import lru_cache
 
 @lru_cache(100)
 def wcwidth(c: str) -> int:
-    """Determine how many columns are needed to display a character in a terminal.
-    Returns -1 if the character is not printable.
+    """Determine how many columns are needed to display a character in a
+    terminal. Returns -1 if the character is not printable.
     Returns 0, 1 or 2 for other characters.
     """
     o = ord(c)
