@@ -3,6 +3,7 @@ from pathlib import Path
 import os
 from difflib import get_close_matches
 import sys
+import json as json_module
 
 from ploomber_scaffold import scaffold as scaffold_project
 import click
@@ -490,49 +491,83 @@ def delete_pipeline(pipeline_id):
               '--force',
               help='Force execution by ignoring status',
               is_flag=True)
-@click.option('--github-number', help="Github's PR number", default=None)
-@click.option('--github-owner', help="Github's owner", default=None)
-@click.option('--github-repo', help="Github's repo", default=None)
-@click.option('--raw', is_flag=True)
-def cloud_build(force, github_number, github_owner, github_repo, raw):
-    """Build pipeline in the cloud
+@click.option('--json', is_flag=True)
+def cloud_build(force, json):
+    """Build pipeline in the cloud:
 
-    Currently in private alpha, ask us for an invite:
-    https://ploomber.io/community
+    $ ploomber cloud build
+
+    Force execution regardless of product status:
+
+    $ ploomber cloud build --force
     """
-    from ploomber.cloud import api
-    runid = api.upload_project(force,
-                               github_number,
-                               github_owner,
-                               github_repo,
-                               verbose=not raw)
-    if raw:
-        click.echo(runid)
+    from ploomber.cloud.api import PloomberCloudAPI
+    api = PloomberCloudAPI()
+    runid = api.build(force,
+                      github_number=None,
+                      github_owner=None,
+                      github_repo=None,
+                      verbose=not json,
+                      task=None)
+    if json:
+        click.echo(json_module.dumps(dict(runid=runid)))
+
+
+@cloud.command(name='task')
+@click.argument('task_name')
+@click.option('-f',
+              '--force',
+              help='Force execution by ignoring status',
+              is_flag=True)
+@click.option('--json', is_flag=True)
+def cloud_task(task_name, force, json):
+    """Build a single pipeline task:
+
+    $ ploomber cloud task {task-name}
+
+    Force task execution regardless of status:
+
+    $ ploomber cloud task {task-name} --force
+    """
+    from ploomber.cloud.api import PloomberCloudAPI
+    api = PloomberCloudAPI()
+    runid = api.build(force,
+                      github_number=None,
+                      github_owner=None,
+                      github_repo=None,
+                      verbose=not json,
+                      task=task_name)
+    if json:
+        click.echo(json_module.dumps(dict(runid=runid)))
 
 
 @cloud.command(name="list")
-def cloud_list():
-    """List cloud executions
+@click.option('--json', is_flag=True)
+def cloud_list(json):
+    """List executions:
 
-    Currently in private alpha, ask us for an invite:
-    https://ploomber.io/community
+    $ ploomber cloud list
     """
-    from ploomber.cloud import api
-    api.runs()
+    from ploomber.cloud.api import PloomberCloudAPI
+    api = PloomberCloudAPI()
+    api.runs(json=json)
 
 
 @cloud.command(name="status")
 @click.argument('run_id')
 @click.option('--watch', '-w', is_flag=True)
-def cloud_status(run_id, watch):
-    """Get details on a cloud execution
+@click.option('--json', is_flag=True)
+def cloud_status(run_id, watch, json):
+    """Get task's execution status:
+
     $ ploomber cloud status {some-id}
 
+    Get task's status of latest execution:
 
-    Currently in private alpha, ask us for an invite:
-    https://ploomber.io/community
+    $ ploomber cloud status @latest
     """
-    from ploomber.cloud import api
+    from ploomber.cloud.api import PloomberCloudAPI
+    api = PloomberCloudAPI()
 
     if watch:
         idle = 5
@@ -553,37 +588,49 @@ def cloud_status(run_id, watch):
             time.sleep(idle)
             cumsum += idle
     else:
-        api.run_detail_print(run_id)
+        api.run_detail_print(run_id, json=json)
 
 
 @cloud.command(name="products")
 @click.option('-d', '--delete', default=None)
-def cloud_products(delete):
-    """List products in cloud workspace
+@click.option('--json', is_flag=True)
+def cloud_products(delete, json):
+    """Manage products (outputs) in cloud workspace
 
-    Currently in private alpha, ask us for an invite:
-    https://ploomber.io/community
+    List products in your workspace:
+
+    $ ploomber cloud products
+
+    Delete products in your workspace:
+
+    $ ploomber cloud products --delete {pattern}
+
+    Delete all .csv files in your workspace:
+
+    $ ploomber cloud products --delete '*.csv'
     """
-    from ploomber.cloud import api
+    from ploomber.cloud.api import PloomberCloudAPI
+    api = PloomberCloudAPI()
 
     if delete:
         api.delete_products(delete)
     else:
-        api.products_list()
+        api.products_list(json=json)
 
 
 @cloud.command(name="download")
 @click.argument('pattern')
 def cloud_download(pattern):
-    """Download products from cloud workspace
+    """Download products from cloud workspace:
+
+    $ ploomber cloud download {pattern}
+
     Download all .csv files:
+
     $ ploomber cloud download '*.csv'
-
-
-    Currently in private alpha, ask us for an invite:
-    https://ploomber.io/community
     """
-    from ploomber.cloud import api
+    from ploomber.cloud.api import PloomberCloudAPI
+    api = PloomberCloudAPI()
     api.products_download(pattern)
 
 
@@ -591,20 +638,32 @@ def cloud_download(pattern):
 @click.argument('run_id')
 @click.option('--image', '-i', is_flag=True)
 @click.option('--watch', '-w', is_flag=True)
-def cloud_logs(run_id, image, watch):
-    """Get logs on a cloud execution
+@click.option('--task', '-t', default=None)
+def cloud_logs(run_id, image, watch, task):
+    """Get logs for all tasks in a cloud run
 
     Get task logs:
-        $ ploomber cloud logs {some-id}
 
+    $ ploomber cloud logs {some-runid}
+
+    Get logs for a given task name:
+
+    $ ploomber cloud logs {some-runid} {some-task-name}
 
     Get Docker image building logs:
-        $ ploomber cloud logs {some-id} --image
 
-    Currently in private alpha, ask us for an invite:
-    https://ploomber.io/community
+    $ ploomber cloud logs {some-runid} --image
+
+    Get task logs for the latest run:
+
+    $ ploomber cloud logs @latest
+
+    Watch logs:
+
+    $ ploomber cloud logs @latest --watch
     """
-    from ploomber.cloud import api
+    from ploomber.cloud.api import PloomberCloudAPI
+    api = PloomberCloudAPI()
 
     if image:
         if watch:
@@ -615,54 +674,134 @@ def cloud_logs(run_id, image, watch):
             while cumsum < timeout:
                 click.clear()
                 time.sleep(idle)
-                api.run_logs_image(run_id, tail=20)
+                done = api.run_logs_image(run_id, tail=20)
                 cumsum += idle
+
+                if done:
+                    break
         else:
             api.run_logs_image(run_id)
     else:
-        api.run_logs(run_id)
+        api.run_logs(run_id, task)
 
 
 @cloud.command(name="abort")
 @click.argument('run_id')
 def cloud_abort(run_id):
-    """Abort a cloud execution
+    """Abort a cloud execution:
+
     $ ploomber cloud abort {some-id}
 
+    Abort latest run:
 
-    Currently in private alpha, ask us for an invite:
-    https://ploomber.io/community
+    $ ploomber cloud abort @latest
     """
-    from ploomber.cloud import api
+    from ploomber.cloud.api import PloomberCloudAPI
+    api = PloomberCloudAPI()
     api.run_abort(run_id)
 
 
 @cloud.command(name="data")
 @click.option('-u', '--upload', default=None)
+@click.option('-p', '--prefix', default=None)
+@click.option('-n', '--name', default=None)
 @click.option('-d', '--delete', default=None)
-def cloud_data(upload, delete):
-    """
-    Manage raw data workspace
+def cloud_data(upload, delete, prefix, name):
+    """Manage input data workspace
 
     List data files:
-        $ ploomber cloud data
+
+    $ ploomber cloud data
 
     Upload data:
-        $ ploomber cloud data --upload path/to/data.parquet
+
+    $ ploomber cloud data --upload dataset.parquet
+
+    Upload to a specific directory:
+
+    $ ploomber cloud data --upload dataset.parquet --prefix my-dataset
+
+    Upload with a specific name:
+
+    $ ploomber cloud data --upload dataset.parquet --name data.parquet
 
     Delete data (deletes all the objects matching the pattern):
-        $ ploomber cloud data --delete '*.parquet'
 
-    Currently in private alpha, ask us for an invite:
-    https://ploomber.io/community
+    $ ploomber cloud data --delete '*.parquet'
+
+    In your notebook (file will be downloaded to data/dataset.parquet):
+
+    >>> from ploomber.cloud import download_data
+
+    >>> download_data('dataset.parquet') # doctest: +SKIP
     """
-    from ploomber.cloud import api
+    from ploomber.cloud.api import PloomberCloudAPI
+    api = PloomberCloudAPI()
 
     # one arg max
 
     if upload:
-        api.upload_data(upload)
+        api.upload_data(upload, prefix=prefix, key=name)
     elif delete:
+        if prefix:
+            click.echo(
+                'prefix has no effect when using -d/--delete. Ignoring...')
+
+        if name:
+            click.echo(
+                'name has no effect when using -d/--delete. Ignoring...')
+
         api.delete_data(delete)
     else:
+        if prefix:
+            click.echo('prefix has no effect when listing files. Ignoring...')
+
+        if name:
+            click.echo('name has no effect when listing files. Ignoring...')
+
         api.data_list()
+
+
+@cloud.command(name="nb")
+@click.argument('path_to_notebook')
+@click.option('--json', is_flag=True)
+def cloud_notebook(path_to_notebook, json):
+    """Run a notebook
+
+    $ ploomber cloud nb path/to/notebook.ipynb
+    """
+    from ploomber.cloud.api import PloomberCloudAPI
+    from ploomber.cloud import io
+
+    # TODO: add unit test
+    path_to_notebook = io.download_notebook_if_needed(path_to_notebook)
+
+    if not Path(path_to_notebook).is_file():
+        raise click.ClickException(f"{path_to_notebook} does not exist")
+
+    api = PloomberCloudAPI()
+    response_upload = api.upload_data(path_to_notebook,
+                                      prefix='notebooks',
+                                      key=Path(path_to_notebook).name,
+                                      version=True,
+                                      verbose=not json)
+    key = response_upload['key']
+
+    if not json:
+        click.echo(f'Triggering execution of {key}...')
+
+    response_execute = api.notebooks_execute(key, json_=json)
+
+    if json:
+        response = {
+            'response_upload': response_upload,
+            'response_execute': response_execute
+        }
+
+        click.echo(json_module.dumps(response))
+    else:
+        runid = response_execute['runid']
+        click.secho(
+            "Done. Monitor Docker build process with:\n  "
+            f"$ ploomber cloud logs {runid} --image --watch",
+            fg='green')
